@@ -39,21 +39,18 @@ class ClientProtocol(asyncio.Protocol):
 class EchoClientProtocol:
 
     transport = None
-    loop = None
     path = None
 
-    def __new__(cls, path=None, loop=None):
+    def __new__(cls, path=None):
         if not hasattr(cls, '_instance'):
             cls._instance = super().__new__(cls)
         return cls._instance
 
-    def __init__(self, path: str = None, loop=None):
-        if not self.loop:
-            self.loop = loop
+    def __init__(self, path: str = None):
         if not self.path:
             self.path = path
-        if self.path is None or self.loop is None:
-            raise Exception("path or loop is not None")
+        if self.path is None:
+            raise Exception("path is not None")
 
     def _processing_data(self, mtype: str, data):
         '''将传入的数据转为服务端可读取的数据'''
@@ -69,23 +66,62 @@ class EchoClientProtocol:
 
     async def create_conn(self):
         '''建立和服务端的连接'''
+        loop = asyncio.get_running_loop()
         if not self.transport or self.transport.is_closing():
-            transport, protocol = await self.loop.create_unix_connection(
+            transport, protocol = await loop.create_unix_connection(
                 lambda: ClientProtocol(self), self.path
             )
             self.transport = transport
 
-    async def send_msg(self, mtype, message):
+    @classmethod
+    async def send_msg(cls, mtype, message):
         '''向服务端发送数据'''
+        loop = asyncio.get_running_loop()
         judge_data_format(mtype, message)
-        # await self.create_conn()
-        self.future = self.loop.create_future()
-        data = self._processing_data(mtype, message)
-        self.transport.write(data)
-        return await self.future
+        cls.future = loop.create_future()
+        data = cls._instance._processing_data(mtype, message)
+        cls._instance.transport.write(data)
+        return await cls.future
 
-    async def close(self):
-        self.future = self.loop.create_future()
-        self.transport.write(b'end')
-        await self.future
-        self.transport.close()
+    @classmethod
+    async def close(cls):
+        loop = asyncio.get_running_loop()
+        cls.future = loop.create_future()
+        cls._instance.transport.write(b'end')
+        await cls.future
+        cls._instance.transport.close()
+
+
+async def async_main():
+    m = EchoClientProtocol("../unix_sock.sock")
+    await m.create_conn() # 建立一个连接
+    await m.send_msg("O", "hello")
+    
+    await EchoClientProtocol.send_msg(
+        "U", [
+            {
+                "key": "key",
+                "name": "name",
+                "status": "status",
+                "endTime": "endTime"
+            }
+        ]
+    )
+    await EchoClientProtocol.send_msg(
+        "H", {"header": "header"}
+    )
+    await EchoClientProtocol.send_msg(
+        "I", [
+            {
+                "key": "key",
+                "name": "name",
+            }
+        ]
+    )
+    await EchoClientProtocol.send_msg(
+        "E", "xxxss"
+    )
+    await m.close()
+    # await m.send_msg("O", "hello3")
+
+asyncio.run(async_main())
