@@ -94,3 +94,7 @@ class EchoServer:
 
     def run(self):
         asyncio.run(self.task())
+
+
+m = EchoServer("../unix_sock.sock")
+m.run()
